
export interface ElementType {
    elementType: 'TOP_IMAGE' | 'TOP_SLIDER' | 'TOP_VIDEO' | 'IMAGE' | 'SLIDER' | 'VIDEO' | 'TEXT' | 'APP_DOWNLOAD' | 'WEAPP' | 'GH' | 'ENTERPRISE_WX' | 'FLOAT_BUTTON',
    comptActive?: boolean
}

/**边距 */
export interface Padding {
    paddingTop: number,//边距 顶部轮播不存在
    paddingBottom: number,//边距 顶部轮播不存在
}
/**文本 */
export interface Text extends ElementType, Padding {
    text: string,
    fontSize: 14 | 15 | 16 | 18 | 20 | 24 | 36,
    fontColor: string,
    textAlignment: 0 | 1 | 2,  // 取值 0: left, 1: middle, 2: right. 默认 0
    fontStyle: 0 | 1,  // 0: 常规, 1: 加粗. 默认 0
}
/**公众号按钮*/
export interface GhButton extends ElementType, Padding {
    fastFollow: 0 | 1// 是否开启一键关注，取值 0: 关闭, 1: 开启. 默认 1
    btnTitle: string, // use_icon 为 0 时，长度限制 1-10 ；use_icon 为 1 时，长度限制 1-8 ； 默认：关注公众号
    fontColor: string, // 按钮文案颜色 默认#FFFFFF
    btnBgColorTheme: string, // 按钮填充色 默认#07C160
    btnBorderColorTheme: string,  // 边框色，#000000-#FFFFFF，默认#FFFFFF
    btnFontType: 0 | 1,  // 按钮文案配置 取值 0: 常规, 1: 加粗. 默认 0
    useIcon: 0 | 1, // 是否使用图标 取值 0: 不使用图标, 1: 使用图标. 默认 0
}

/**添加商家微信按钮*/
export interface WxAutoButton extends Padding, ElementType {
    cropId?: string,             // 绑定的企业 id
    groupId?: number,            // 客服组 id
    btnTitle: string,            // 按钮文案,
    fontColor: string,           // 按钮文案颜色，#000000-#FFFFFF，默认#FFFFFF
    btnBgColorTheme: string,     // 按钮填充色，#000000-#FFFFFF，默认#07C160
    btnBorderColorTheme: string, // 边框色，#000000-#FFFFFF，默认#FFFFFF
    btnFontType: 0 | 1,          // 字体粗细 0常用 1加粗
    useIcon: 0 | 1,              // 图标开启关闭 取值 0: 不使用图标, 1: 使用图标. 默认 0
}

/**跳转链接按钮*/
export interface LinkButton extends Padding {
    widgetTypeV2: "link",
    widgetType: "button",
    type: "21",
    name: "跳转链接",
    btnTitle: string,
    subType: "0",
    fontSize: "30",
    fontColor: string,
    btnType: "0",
    borderSize: "0",
    btnHeight: "80",
    btnBgColorTheme: string,
    btnBorderColorTheme: string,
    btnFontType: '0' | '1',
    btnStyle: "1",
    cornerRadius: 4,
    useIcon: '0' | '1',
    id: "widget_1632641482474_3",
    mpJumpType: "1",
    origBtnJumpUrl: string,
    btnJumpUrl: ""
}

/**img */
export interface Img extends ElementType, Padding {
    imageUrl: string,
    width: number,
    height: number,
}
/**top_img */
export interface TopImg extends ElementType {
    imageUrl: string,
    width: number,
    height: number,
    adLocation: 'sns' | 'gzh',  // sns 代表朋友圈, gzh 代表公众号
    outerStyle?: 0 | 1, //ad_location 为 sns 时必填. 取值 0: 常规广告, 1: 卡片广告
}
/**top_Video */
export interface TopVideo extends ElementType {
    videoUrl: string,
    width: number,
    height: number,
    adLocation: 'sns' | 'gzh',
    outerStyle?: 0 | 1 | 2, //为 sns 时必填 0: 常规广告, 1: 基础卡片广告, 2: 全幅卡片广告
    usedForOuter?: 0 | 1,  //0:顶部素材用于广告外层, 1:顶部素材不用于广告外层. 默认 0. 仅微信平台账号有效. outer_style=1 时选填
}

/** 图文复合组件标题类型 */
export interface ImageTextContentTitle {
    name: "标题",
    content: string,
    fontColor: string,
    fontSize: "32",
    layoutHeight: "44",
    layoutWidth: "410",
    maxLines: "1",
    showType: "1",
    type: "1",
    wxad_IsSubNode: "1"
}
/** 图文复合描述标题类型 */
export interface ImageTextContentDesc {
    name: string,  // text = 描述 price = 价格
    content: string, // 内容
    fontColor: string,  // 字体颜色
    fontSize: string,  // 字体大小
    layoutHeight: "40",
    layoutWidth: "410",
    paddingTop: "8",
    type: "1",
    wxad_IsSubNode: "1",
    showType?: "1",  // 选择价格才有
}
/** 图文复合组件跳转链接类型 */
export interface ImageTextContentLink {
    widgetTypeV2: "link",
    widgetType: "button",
    borderSize: "2",
    btnBgColorTheme: string,  // "#07C160"
    btnBorderColorTheme: string,   // "#FFFFFF"
    btnFontType: "0",
    btnHeight: "60",
    btnJumpUrl: "",
    btnStyle: "1",
    btnTitle: string,   // "了解详情"
    btnType: "0",
    fontColor: string,    // "#FFFFFF"
    fontSize: "26",
    name: string,   // "跳转链接"
    origBtnJumpUrl: "",
    layoutWidth: "152",
    layoutHeight: "60",
    paddingBottom: "0",
    paddingLeft: "0",
    paddingRight: "0",
    paddingTop: "28",
    subType: "0",
    mpJumpType: "1",
    type: "21",
    cornerRadius: "4"
}
/** 图文复合组件关注公众号类型 */
export interface ImageTextContentGh {
    widgetTypeV2: string, //"gh",
    widgetType: string, //"button",
    type: string, //"21",
    borderSize: string, //"0",
    name: string, //"商品关注公众号",
    btnTitle: string,  // "关注公众号"
    subType: '17' | '1',
    fontSize: string, //"26",
    fontColor: string,  // "#FFFFFF"
    btnType: string, //"0",
    btnBgColorTheme: string,  // "#07C160"
    btnBorderColorTheme: string,  // "#FFFFFF"
    btnFontType: '0' | '1',
    btnStyle: string, //"1",
    cornerRadius: number | string, //4,
    useIcon: string, //"0",
    field21_1: {
        origBtnJumpUrl: string,
        wxad_guide_group_id: string
    },
    id: string,   // "widget_1634288817126_3"
    layoutWidth: string, //"152",
    layoutHeight: string, //"60",
    btnHeight?: string,   //"60",
    paddingTop?: string,  //"28",
    paddingBottom?: string, //"0",
    paddingRight?: string,  // "0"
    paddingLeft?: string,  // "0"
    horizontalAlignment?: string  // "1"
}
/** 图文复合组件添加商家微信按钮 */
export interface ImageTextContentWxAuto {
    widgetTypeV2: string, // "enterprise_wx_auto"
    widgetType: string, // "button"
    type: string, // "21"
    name: string, // "商品添加商家微信"
    btnTitle: string, //"联系商家",
    subType: string, //"15"
    fontSize: string,//"26",
    fontColor: string,//"#FFFFFF",
    btnType: string, // "0"
    borderSize: string, // "0"
    btnBgColorTheme: string, // "#07C160",
    btnBorderColorTheme: string, //"#FFFFFF",
    btnFontType: string, // "0"
    btnStyle: string, // "1"
    cornerRadius: number | string, //4,
    useIcon: string, //"0",
    mpJumpType: string, //"1",
    origBtnJumpUrl: string,
    btnJumpUrl: string, //"",
    corpid: string,//"wp7eXwDAAA4NWRcT0uN05GKQesjmgB0g",
    groupid: number | null,
    h5_config_id: string, //"6eeeabc55c3087ea251505ec8560371e",
    wxapp_config_id: string, //"bee1788a8cbf0bbab69d3bfc5917231e",
    qrUrl: string,//"https://wework.qpic.cn/wwpic/87591_JQGte4L-Tc21VZW_1645432835/0",
    needUpdateQrUrl: number, //0,
    qrExtInfo: string,//"{\"qrType\":1,\"corpid\":\"wp7eXwDAAA4NWRcT0uN05GKQesjmgB0g\",\"groupid\":215982,\"useSet\":0}",
    serviceType: string, //"1",
    chatGroupName: string,
    id: string,
    layoutWidth: string, //"152",
    layoutHeight: string, //"60",
    btnHeight?: string,//"60",
    paddingTop?: string, //"28",
    paddingBottom?: string, //"0",
    paddingRight?: string, //"0",
    paddingLeft?: string, //"0",
}


/** 图文复合组件单个内容 */
export interface ImageText1Content {
    layoutHeight: string,  // "228" 
    layoutWidth: string,  // "670"
    type: string,  // "103"
    subType: string,  // "1"
    jumpMode: string,  // "btn_jump" "total_jump"
    layoutItems: {
        componentItem: [{
            name: "图片",
            layoutHeight: "180",
            layoutWidth: "180",
            paddingTop: "24",
            paddingLeft: "24",
            pureImageUrl: string,
            type: "41",
            imageMd5: string,
            cornerRadius: "4",
            materialId: "2276131704",
            wxad_IsSubNode: "1"
        }, {
            layoutHeight: "228",
            layoutWidth: "470",
            paddingLeft: "24",
            paddingTop: "24",
            paddingRight: "40",
            subType: "0",
            type: "103",
            descType: string,  // 文字 text 价格 price
            wxad_IsSubNode: "1",
            layoutItems: {
                componentItem: Array<ImageTextContentTitle | ImageTextContentDesc | ImageTextContentLink | ImageTextContentGh>
            }
        }]
    }
}

export interface ImageTextOsButtonLink {
    widgetTypeV2: "link",
    widgetType: "button",
    borderSize: "0",
    btnBgColorTheme: "clear",
    btnBorderColorTheme: "clear",
    btnFontType: "0",
    btnHeight: "228",
    btnJumpUrl: "",
    btnStyle: "1",
    btnTitle: "",
    btnType: "0",
    fontColor: "clear",
    fontSize: "26",
    name: string,   // "跳转链接"
    origBtnJumpUrl: string,
    layoutWidth: "750",
    layoutHeight: "228",
    paddingBottom: "0",
    paddingLeft: "0",
    paddingRight: "0",
    paddingTop: "0",
    subType: "0",
    fengyeId: "0",
    fengyeUrl: "",
    mpJumpType: "1",
    type: "21",
    cornerRadius: "4"
}

export interface ImageTextOsButtonGh {
    widgetTypeV2: "gh",
    widgetType: "button",
    type: "21",
    name: "商品关注公众号",
    btnTitle: "",
    subType: "17",
    wxad_guide_group_status: false,
    fontSize: "26",
    fontColor: "clear",
    btnType: "0",
    borderSize: "0",
    btnHeight: "228",
    btnBgColorTheme: "clear",
    btnBorderColorTheme: "clear",
    btnFontType: "0",
    btnStyle: "1",
    paddingTop: "0",
    paddingBottom: "0",
    paddingRight: "0",
    paddingLeft: "0",
    cornerRadius: 4,
    useIcon: "0",
    field21_1: {
        origBtnJumpUrl: "",
        wxad_guide_group_id: ""
    },
    id: "widget_1634288817126_3",
    layoutWidth: "750",
    layoutHeight: "228"
}

/** 图文复合组件单个 */
export interface Shelfnew extends Padding {
    widgetTypeV2: string,   // 图文复合组件 shelfnew
    widgetType: string,     // 图文复合组件 shelfnew
    name: string,    // "图文复合组件"
    type: string,     // 图文复合组件 单个 "104" 多个 "103"
    id: string,       // "widget_1634190280938_1"
    layoutHeight: string, // "228"
    layoutWidth: string,  // "670"
    // paddingTop: "20",
    // paddingBottom: "20",
    // paddingLeft: "40",
    // paddingRight: "40",
    borderColor: string,   // "#e5e5e5"
    bgColor: string,   // #FFFFFF
    borderSize: number,  // 1
    cornerRadius: number,  // 8
    isChooseJump: number,  // 1
    layoutItems: {
        componentItem: Array<ImageText1Content | ImageTextOsButtonLink | ImageTextOsButtonGh>
    }
}



/** 悬浮组件 */
export interface Floatbutton {
    elementType: 'FLOAT_BUTTON',
    styleType: 0 | 1 | 2,  // 取值 0: 图片+title+desc，1: title+desc, 2: title
    imageUrl?: string, // style_type=0 时必填. 悬浮组件图片 id. 图片尺寸 96x96
    title: string, // 悬浮组件标题
    titleColor?: string,  //悬浮组件标题颜色 "#171717",
    desc?: string,   // 描述
    descColor?: string, //悬浮组件描述颜色. 默认#4C4C4C
    appearType?: 0 | 1, //出现方式 取值 0. 进入页面时出现, 1. 滑动页面时出现. 默认 0 如果 page_specs_list 只有一页必须为 0
    disappearType?: 0 | 1, //消失方式 取值 0.不消失, 1.滑至页面底部时消失, 默认 0 如果 page_specs_list 只有一页必须为 0
    forbidPageList?: number[], // 悬浮按钮不出现的页面数组. [1,2]代表第 1,2 页不出现悬浮按钮, 依次类推.
    componentItem: Omit<GhButton, 'btnBorderColorTheme' | 'useIcon' | 'paddingTop' | 'paddingBottom'> | Omit<WxAutoButton, 'btnBorderColorTheme' | 'useIcon' | 'paddingTop' | 'paddingBottom'>
}
/**top_slider 顶部轮播*/
export interface TopSlider extends ElementType {
    imageUrlList: string[],
    width: number,
    height: number,
    activeIndex?: number
}